@@ -46,6 +46,7 @@ class IndexView(TemplateView):
         context.update({
             'datatableview_version': '.'.join(map(str, datatableview.__version_info__)),
             'django_version': django.get_version(),
+            'datatables_version': '1.10.0',
         })
 
         return context
@@ -602,6 +603,46 @@ class HelpersReferenceDatatableView(DemoMixin, XEditableDatatableView):
     """
 
 
+class PerRequestOptionsDatatableView(DemoMixin, DatatableView):
+    """
+    Care must be taken to modify the options object on the View class: because it is defined as a
+    class attribute, there is only one copy of it in memory, and changing it is not thread safe.
+    
+    To safely change the options at runtime, copy the main options dictionary and then make a deep
+    of the columns list (copying the outer dictionary will not do this automatically).  The simplest
+    way to do this is via a call to the built-in ``copy.deepcopy`` function.
+    """
+    model = Entry
+    datatable_options = {
+        'columns': [
+            'id',
+            'headline',
+        ],
+    }
+
+    def get_datatable_options(self):
+        from copy import deepcopy
+        options = deepcopy(self.datatable_options)
+        options['columns'].append("blog")
+        return options
+
+    implementation = u"""
+    class PerRequestOptionsDatatableView(DemoMixin, DatatableView):
+        model = Entry
+        datatable_options = {
+            'columns': [
+                'id',
+                'headline',
+            ],
+        }
+
+        def get_datatable_options(self):
+            from copy import deepcopy
+            options = deepcopy(self.datatable_options)
+            options['columns'].append("blog")
+            return options
+    """
+
 class OrderingDatatableView(DemoMixin, DatatableView):
     """
     Default ordering is normally controlled by the model's Meta option ``ordering``, which is a list
@@ -796,20 +837,22 @@ class BootstrapTemplateDatatableView(DemoMixin, DatatableView):
     template!
 
     This gets the table itself looking better, but the rest of the controls added by dataTables.js
-    are a little lackluster by comparison.  To fix this, download the integration files from
-    <a href="https://github.com/DataTables/Plugins/tree/master/integration/bootstrap/">https://github.com/DataTables/Plugins/tree/master/integration/bootstrap/</a>
-    and then add them to the main template:
+    are a little lackluster by comparison.  To fix this, reference the latest integration helper CSS
+    and javascript support files in the template:
     
     <pre>
-    &lt;link href="{{ STATIC_URL }}css/dataTables.bootstrap.css" rel="stylesheet" /&gt;
+    &lt;link href="//cdn.datatables.net/plug-ins/be7019ee387/integration/bootstrap/3/dataTables.bootstrap.css" rel="stylesheet" /&gt;
     </pre>
     <pre>
-    &lt;script src="{{ STATIC_URL }}js/dataTables.bootstrap.js"&gt;&lt;/script&gt;
+    &lt;script src="//cdn.datatables.net/plug-ins/be7019ee387/integration/bootstrap/3/dataTables.bootstrap.js"&gt;&lt;/script&gt;
     </pre>
 
-    Alternately, you can use the set of static resources from
-    <a href="https://github.com/Jowin/Datatables-Bootstrap3/">https://github.com/Jowin/Datatables-Bootstrap3/</a>,
-    which do the same thing with mild variances.
+    See <a href="https://datatables.net/examples/styling/bootstrap.html">the official datatables
+    documentation</a> on the subject for more information.
+
+    WARNING:
+    The pagination buttons are currently a bit strange with Bootstrap 3.1.1 and Datatables 1.10.0.
+    Please make sure you are using the latest integration files by checking the link just above.
     """
     model = Entry
     datatable_options = {
@@ -1105,8 +1148,9 @@ class EmbeddedTableDatatableView(DemoMixin, TemplateView):
         context = super(EmbeddedTableDatatableView, self).get_context_data(**kwargs)
 
         satellite_view = SatelliteDatatableView()
+        model = satellite_view.model
         options = satellite_view.get_datatable_options()
-        datatable = get_datatable_structure(reverse('satellite'), options)
+        datatable = get_datatable_structure(reverse('satellite'), options, model=model)
 
         context['datatable'] = datatable
         return context
@@ -1117,8 +1161,9 @@ class EmbeddedTableDatatableView(DemoMixin, TemplateView):
             context = super(EmbeddedTableDatatableView, self).get_context_data(**kwargs)
 
             satellite_view = SatelliteDatatableView()
+            model = satellite_view.model
             options = satellite_view.get_datatable_options()
-            datatable = get_datatable_structure(reverse('satellite'), options)
+            datatable = get_datatable_structure(reverse('satellite'), options, model=model)
 
             context['datatable'] = datatable
             return context
